@@ -1,5 +1,5 @@
 package UNIVERSAL::require;
-$UNIVERSAL::require::VERSION = '0.13_1';
+$UNIVERSAL::require::VERSION = '0.15_01';
 
 # We do this because UNIVERSAL.pm uses CORE::require().  We're going
 # to put our own require() into UNIVERSAL and that makes an ambiguity.
@@ -8,7 +8,9 @@ BEGIN { require UNIVERSAL }
 
 package UNIVERSAL;
 
+use 5.006;
 use strict;
+use warnings;
 
 use vars qw($Level);
 $Level = 0;
@@ -181,6 +183,7 @@ See F<http://www.perl.com/perl/misc/Artistic.html>
 
 Michael G Schwern <schwern@pobox.com>
 
+Now maintained by Neil Bowers (NEILB).
 
 =head1 SEE ALSO
 
